#
# spec file for package python-editdistance
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%{?sle15allpythons}

Name:           python-editdistance
Version:        0.6.2
Release:        2.5
Summary:        An implementation of the edit distance (Levenshtein distance)
License:        MIT
URL:            https://www.github.com/aflc/editdistance
# Switch to github tarball until gh#roy-ht/editdistance#102 is merged
Source:         https://github.com/roy-ht/editdistance/archive/refs/tags/v%{version}.tar.gz#/editdistance-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  python-rpm-macros
Requires:       python-base
%python_subpackages

%description
An implementation of the edit distance (Levenshtein distance).

This library implements Levenshtein distance with C++ and Cython.

The algorithm used in this library is proposed by Heikki Hyyrö,
"Explaining and extending the bit-parallel approximate string
matching algorithm of Myers", (2001).

%package devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}
Requires:       python-base

%description devel
This package contains the files needed for binding the %{name} C module.

%prep
%setup -q -n editdistance-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pytest_arch

%files %{python_files}
%license LICENSE
%doc README.rst
%exclude %{python_sitearch}/editdistance/*.h
%{python_sitearch}/editdistance
%{python_sitearch}/editdistance-%{version}*info

%files %{python_files devel}
%{python_sitearch}/editdistance/*.h

%changelog
* Wed Nov 22 2023 Matthias Bach <marix@marix.org>
- Also build for modern Python on Leap
* Tue Feb 21 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.6.2:
  * Support cimport usage
- Add missing Requires on python-base for the devel package.
* Wed Nov  3 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.6.0:
  * No code changes, include binary wheels for new version of python.
- Switch from nose to pytest, dropping the awful mv calls.
- LICENSE now shipped in sdist.
* Mon Mar 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.5.3:
  * Exception raised when I pass a number, but I can not catch it
  * Consider exposing an api that's not called `eval`
* Thu Feb 14 2019 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
- Add Requires python-base
- Create subpackage devel
- Add README.rst which includes the license
- Update from v0.3.1 (March 2016) to v0.5.2 (Sept 2018)
  * Improved README
  * Added basic test suite
* Sat Mar 18 2017 jengelh@inai.de
- Ensure neutrality of descriptions
* Mon Mar  6 2017 jmatejek@suse.com
- initial commit for v0.3.1
